MetaCredo. Check. Consistency. ExceptionNames
(MetaCredo v0.1.0)
Detects exception or error container names that do not end in "Error" or "Exception". Consistent naming makes it easier to identify error types at a glance.
For example, InvalidInput should be InvalidInputError.
Category: Consistency / Priority: normal