MetaCredo.Check.Observability.MissingTelemetryInObanWorker (MetaCredo v0.1.0)

Detects background job processing functions (e.g. Oban worker perform/1) without telemetry instrumentation. Background jobs should emit metrics for monitoring, debugging, and alerting on job execution.

Category: Observability / Priority: normal

Configuration

Accepts the following parameters via .metacredo.exs:

  • job_indicators - Function/module name fragments that indicate a job context (default: {:sigil_W, [delimiter: "[", line: 6, column: 23], [{:<<>>, [line: 6, column: 23], ["perform execute process run worker job task handler"]}, []]})
  • telemetry_indicators - Function name fragments that indicate telemetry calls (default: {:sigil_W, [delimiter: "[", line: 7, column: 29], [{:<<>>, [line: 7, column: 29], ["telemetry emit log trace metric record measure monitor"]}, []]})