MetaCredo. Check. Readability. LongParameterList
(MetaCredo v0.1.0)
Detects functions with too many parameters. Long parameter lists are hard to remember and use correctly. Consider grouping related parameters into a struct, map, or keyword list.
Category: Readability / Priority: normal
Configuration
Accepts the following parameters via .metacredo.exs:
max_params- Maximum allowed parameters per function (default: 5) (default:5)