MetaCredo. Check. Warning. LazyLogging
(MetaCredo v0.1.0)
Detects Logger calls that use string interpolation directly instead of wrapping the message in an anonymous function. Eager interpolation performs the string building even when the log level is disabled.
Use Logger.info(fn -> "msg: #{val}" end) instead.
Category: Warning / Priority: normal