MetaCredo. Issue
(MetaCredo v0.1.0)
Represents a single issue found during analysis.
Mirrors Credo.Issue but operates on MetaAST nodes.
Summary
Functions
Returns the default exit status for a given category.
Converts a priority atom to its numeric value.
Types
@type priority() :: :higher | :high | :normal | :low | :ignore
@type severity() :: :error | :warning | :info | :refactoring_opportunity
@type t() :: %MetaCredo.Issue{ category: atom(), check: module(), column: pos_integer() | nil, exit_status: non_neg_integer(), filename: String.t() | nil, line_no: pos_integer() | nil, message: String.t(), metadata: map(), priority: priority() | integer(), severity: severity(), trigger: String.t() | nil }
Functions
@spec exit_status_for(atom()) :: non_neg_integer()
Returns the default exit status for a given category.
Converts a priority atom to its numeric value.